@@ -1,5 +1,5 @@
 /*
- * Copyright (C) Pedram Pourang (aka Tsu Jan) 2020 <tsujan2000@gmail.com>
+ * Copyright (C) Pedram Pourang (aka Tsu Jan) 2022 <tsujan2000@gmail.com>
  *
  * Kvantum is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -88,6 +88,10 @@ WindowManager::WindowManager (QObject *parent, Drag drag, bool dragFromBtns) :
                dragDelay_ (qMax (QApplication::startDragTime(), 500)),
                doubleClickInterval_ (QApplication::doubleClickInterval()),
                isDelayed_ (false),
+#if (QT_VERSION >= QT_VERSION_CHECK(6,0,0))
+               DblClickSent_ (false),
+               preventDbClick_ (false),
+#endif
                dragAboutToStart_ (false),
                dragInProgress_ (false),
                locked_ (false),
@@ -178,6 +182,7 @@ bool WindowManager::eventFilter (QObject *object, QEvent *event)
       break;
 
     case QEvent::WindowBlocked:
+    case QEvent::FocusOut: // e.g., a popup is shown
     case QEvent::Leave:
     case QEvent::Hide:
       if (object == winTarget_.data())
@@ -252,8 +257,21 @@ void WindowManager::timerEvent (QTimerEvent *event)
                    possible to drag from button-like widgets safely (as in GTK). */
           QMouseEvent e (QEvent::MouseButtonRelease,
                          QPoint (-1, -1),
+#if (QT_VERSION >= QT_VERSION_CHECK(6,4,0))
+                         QCursor::pos(),
+#endif
                          Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
           qApp->sendEvent (widgetTarget_.data(), &e);
+#if (QT_VERSION >= QT_VERSION_CHECK(6,0,0))
+          /* NOTE: With Qt5, a leave event will be sent automatically if the drag is
+                   finished and the cursor moves inside the window but outside the widget.
+                   That doesn't happen with Qt6, and the widget stays in the hover state,
+                   unless the cursor enters and leaves it. So, we send a leave event here.
+                   Fortunately, if the widget is under the cursor after the drag is finished,
+                   an enter event will be sent to it automatically, restoring its hover state. */
+          QEvent e1 (QEvent::Leave);
+          qApp->sendEvent (widgetTarget_.data(), &e1);
+#endif
         }
         if (!_WMExists) return; // see mousePressEvent for the reason
         if (winTarget_)
@@ -277,6 +295,7 @@ bool WindowManager::mousePressEvent (QObject *object, QEvent *event)
   if (!w) return false;
   QPoint winDragPoint = mouseEvent->pos();
 
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
   if (doubleClickTimer_.isActive())
   {
     doubleClickTimer_.stop();
@@ -289,6 +308,7 @@ bool WindowManager::mousePressEvent (QObject *object, QEvent *event)
     }
   }
   doubleClickTimer_.start (doubleClickInterval_, this);
+#endif
 
   if (qApp->activePopupWidget())
   { // -> the workaround in timerEvent()
@@ -307,9 +327,11 @@ bool WindowManager::mousePressEvent (QObject *object, QEvent *event)
     /* if the window is changed, start a new drag */
   }
 
+#if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
   /* remember the window and its drag point */
   lastWin_ = w;
   lastWinDragPoint_ = winDragPoint;
+#endif
 
   /* find the widget */
   QWidget *widget = nullptr;
@@ -335,12 +357,79 @@ bool WindowManager::mousePressEvent (QObject *object, QEvent *event)
     if (!widget)
       widget = activeWin;
   }
-  if (!widget) return false;
+  if (!widget
+      /* this condition is especially needed under Wayland because
+         "QMouseEvent::globalPosition()" isn't reliable there */
+      || widget->window()->windowHandle() != w)
+  {
+    return false;
+  }
 
 #if (QT_VERSION < QT_VERSION_CHECK(6,0,0))
   widgetDragPoint_ = widget->mapFromGlobal (mouseEvent->globalPos()); // needed by canDrag()
 #else
   widgetDragPoint_ = widget->mapFromGlobal (mouseEvent->globalPosition().toPoint()); // needed by canDrag()
+
+  preventDbClick_ = false;
+  if (doubleClickTimer_.isActive())
+  {
+    /* NOTE: With Qt6, the double click event isn't sent automatically after this press event.
+             As a workaround, a double click event is sent explicitly here. Unfortunately,
+             a third mouse press might also create a double click event if it happens shortly
+             afterward, but we handle that too. */
+    if (lastWin_.data() == w
+        && QPoint (winDragPoint - lastWinDragPoint_).manhattanLength() < dragDistance_)
+    { // don't drag by double (or triple) clicking
+      if (clickedWidget_.data() == widget)
+      {
+        if (mouseEvent->flags() & Qt::MouseEventCreatedDoubleClick)
+        { // Qt6's problem doesn't exist anymore
+          clickedWidget_.clear();
+          DblClickSent_ = false;
+        }
+        else
+        { // send a double click event
+          DblClickSent_ = true;
+          auto e = new QMouseEvent (QEvent::MouseButtonDblClick, widgetDragPoint_,
+#if (QT_VERSION >= QT_VERSION_CHECK(6,4,0))
+                                    QCursor::pos(),
+#endif
+                                    Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+          qApp->postEvent (widget, e);
+        }
+      }
+      else
+      {
+        if (DblClickSent_
+            && (mouseEvent->flags() & Qt::MouseEventCreatedDoubleClick))
+        {
+          /* Qt6 sends a double click event with the third mouse press. We prevent
+             that and send a normal press event instead. We also set "clickedWidget_",
+             to send a double click event with the fourth mouse press, etc. */
+          preventDbClick_ = true;
+          clickedWidget_ = widget;
+          auto e = new QMouseEvent (QEvent::MouseButtonPress, widgetDragPoint_,
+#if (QT_VERSION >= QT_VERSION_CHECK(6,4,0))
+                                    QCursor::pos(),
+#endif
+                                    Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+          qApp->postEvent (widget, e);
+        }
+        DblClickSent_ = false;
+      }
+      resetDrag();
+      unlock();
+      lastWinDragPoint_ = winDragPoint;
+      /* restart the timer for checking the next click */
+      doubleClickTimer_.start (doubleClickInterval_, this);
+      return false;
+    }
+  }
+  doubleClickTimer_.start (doubleClickInterval_, this);
+  clickedWidget_.clear();
+  /* remember the window and its drag point */
+  lastWin_ = w;
+  lastWinDragPoint_ = winDragPoint;
 #endif
 
   /* check if the widget can be dragged */
@@ -367,7 +456,11 @@ bool WindowManager::mousePressEvent (QObject *object, QEvent *event)
 
   /* Because the widget may react to mouse press events,
      we first send a press event to it. */
-  QMouseEvent mousePress (QEvent::MouseButtonPress, widgetDragPoint_, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+  QMouseEvent mousePress (QEvent::MouseButtonPress, widgetDragPoint_,
+#if (QT_VERSION >= QT_VERSION_CHECK(6,4,0))
+                          QCursor::pos(),
+#endif
+                          Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
   qApp->sendEvent (widget, &mousePress);
 
   /* Theoretically, it's possible that the WindowManager instance
@@ -410,7 +503,11 @@ bool WindowManager::mousePressEvent (QObject *object, QEvent *event)
 
   /* Send a move event to the target window with the same position.
      If received, it is caught to actually start the drag. */
-  QMouseEvent mouseMove (QEvent::MouseMove, winDragPoint, Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
+  QMouseEvent mouseMove (QEvent::MouseMove, winDragPoint,
+#if (QT_VERSION >= QT_VERSION_CHECK(6,4,0))
+                         QCursor::pos(),
+#endif
+                         Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
   qApp->sendEvent (w, &mouseMove);
 
   /* NOTE: The event should be consumed; otherwise, mouseover effects
@@ -476,8 +573,14 @@ bool WindowManager::mouseReleaseEvent (QEvent *event)
     QMouseEvent *mouseEvent = static_cast<QMouseEvent*>(event);
     if (mouseEvent->button() == Qt::LeftButton)
     {
+#if (QT_VERSION >= QT_VERSION_CHECK(6,0,0))
+      clickedWidget_ = widgetTarget_.data(); // needed by a workaround for double clicking
+#endif
       auto e = new QMouseEvent (QEvent::MouseButtonRelease,
                                 widgetDragPoint_,
+#if (QT_VERSION >= QT_VERSION_CHECK(6,4,0))
+                                QCursor::pos(),
+#endif
                                 Qt::LeftButton, Qt::LeftButton, Qt::NoModifier);
       qApp->postEvent (widgetTarget_.data(), e);
       resetDrag();
@@ -865,9 +968,27 @@ bool WindowManager::AppEventFilter::eventFilter (QObject *object, QEvent *event)
           parent_->lastPressedWidget_ = widget;
       }
     }
+#if (QT_VERSION >= QT_VERSION_CHECK(6,0,0))
+    else if (object == parent_->clickedWidget_.data()
+             // ensure that a double click shouldn't be consumed instead
+             && !parent_->preventDbClick_)
+    { // consume this extra press event created by our enforced double click
+      parent_->clickedWidget_.clear();
+      return true;
+    }
+#endif
     return false;
   }
 
+#if (QT_VERSION >= QT_VERSION_CHECK(6,0,0))
+  if (parent_->preventDbClick_ && !parent_->isLocked()
+      && event->type() == QEvent::MouseButtonDblClick
+      && object == parent_->clickedWidget_.data())
+  {
+    return true;
+  }
+#endif
+
   /* If a drag is in progress, no event will be received. Therefore,
      we wait for the first mouse move or press event that is received
      by any object in the application to unclock the window. */
