@@ -194,8 +194,6 @@ void Style::drawBg(QPainter *p, const QWidget *widget) const
     p->restore();
 }
 
-static QSet<const QWidget*> movedMenus;
-
 static inline bool isAnimatedScrollArea(QWidget *w)
 {
   auto sa = qobject_cast<QAbstractScrollArea*>(w);
@@ -229,16 +227,13 @@ bool Style::eventFilter(QObject *o, QEvent *e)
           if (!progressbars_.contains(w))
           {
             progressbars_.insert(w, 0);
+            connect(w, &QObject::destroyed, this, &Style::forgetProgressBar);
             if (!progressTimer_->isActive())
               progressTimer_->start(50);
           }
         }
-        else if (!progressbars_.isEmpty())
-        {
-          progressbars_.remove(w);
-          if (progressbars_.size() == 0)
-            progressTimer_->stop();
-        }
+        else
+          forgetProgressBar(o);
         isKisSlider_ = false;
       }
       else if (w->isWindow()
@@ -962,6 +957,7 @@ bool Style::eventFilter(QObject *o, QEvent *e)
                               || w->windowType() == Qt::ToolTip))
       {
         popupOrigins_.insert(w, animatedWidget_);
+        connect(w, &QObject::destroyed, this, &Style::forgetPopupOrigin);
       }
 
       if (QProgressBar *pb = qobject_cast<QProgressBar*>(o))
@@ -969,7 +965,10 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         if (pb->maximum() == 0 && pb->minimum() == 0)
         {
           if (!progressbars_.contains(w))
+          {
             progressbars_.insert(w, 0);
+            connect(w, &QObject::destroyed, this, &Style::forgetProgressBar);
+          }
           if (!progressTimer_->isActive())
             progressTimer_->start(50);
         }
@@ -1003,7 +1002,7 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         }
 #endif
 
-        if (movedMenus.contains(w)) break; // already moved
+        if (movedMenus_.contains(w)) break; // already moved
         /* "magical" condition for a submenu */
         QPoint parentMenuCorner;
         QMenu *parentMenu = qobject_cast<QMenu*>(QApplication::activePopupWidget());
@@ -1055,7 +1054,7 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         qreal dX = 0, dY = 0;
         /* this gives the real position AFTER pending movements
            because it's QWidgetData::crect (Qt -> qwidget.h) */
-        QRect g(w->geometry());
+        const QRect g(w->geometry());
 
         /* WARNING: If compositing is stopped here, we aren't responsible.
                     A check for the state of compositing at this very moment
@@ -1067,6 +1066,8 @@ bool Style::eventFilter(QObject *o, QEvent *e)
 
           dY -= menuShadow_.at(1); // top shadow
 
+          QPushButton *pBtn = nullptr;
+          QToolButton *tBtn = nullptr;
           if (w->layoutDirection() == Qt::RightToLeft)
           { // see explanations for ltr below
             dX += menuShadow_.at(2);
@@ -1080,62 +1081,61 @@ bool Style::eventFilter(QObject *o, QEvent *e)
                       - static_cast<qreal>(getMenuMargin(true)); // workaround for an old Qt bug
               }
             }
-            else
+            else if (parentMenubar)
             {
-              if (parentMenubar)
-              {
-                QString group = tspec_.merge_menubar_with_toolbar ? "Toolbar" : "MenuBar";
-                if (parentMenubar->mapToGlobal(QPoint(0,0)).y() > g.bottom())
-                  dY +=  menuShadow_.at(1) + menuShadow_.at(3) + static_cast<qreal>(getFrameSpec(group).top);
-                else
-                  dY -= static_cast<qreal>(getFrameSpec(group).bottom);
-
-                QRect activeG = parentMenubar->actionGeometry(parentMenubar->activeAction());
-                QPoint activeTopLeft = parentMenubar->mapToGlobal(activeG.topLeft());
-                if (g.right() + 1 > activeTopLeft.x() + activeG.width())
-                { // Qt positions the menu wrongly in this case but we don't add a workaround
-                  dX -= menuShadow_.at(2);
-                  qreal delta = menuShadow_.at(2)
-                                - static_cast<qreal>(g.right() + 1 - (activeTopLeft.x() + activeG.width()));
-                  if (delta > 0)
-                    dX += delta;
-                  else
-                    dX -= qMin(menuShadow_.at(0), -delta);
-                }
-              }
+              QString group = tspec_.merge_menubar_with_toolbar ? "Toolbar" : "MenuBar";
+              if (parentMenubar->mapToGlobal(QPoint(0,0)).y() > g.bottom())
+                dY +=  menuShadow_.at(1) + menuShadow_.at(3) + static_cast<qreal>(getFrameSpec(group).top);
               else
+                dY -= static_cast<qreal>(getFrameSpec(group).bottom);
+
+              QRect activeG = parentMenubar->actionGeometry(parentMenubar->activeAction());
+              QPoint activeTopLeft = parentMenubar->mapToGlobal(activeG.topLeft());
+              if (g.right() + 1 > activeTopLeft.x() + activeG.width())
+              { // Qt positions the menu wrongly in this case but we don't add a workaround
+                dX -= menuShadow_.at(2);
+                qreal delta = menuShadow_.at(2)
+                              - static_cast<qreal>(g.right() + 1 - (activeTopLeft.x() + activeG.width()));
+                if (delta > 0)
+                  dX += delta;
+                else
+                  dX -= qMin(menuShadow_.at(0), -delta);
+              }
+            }
+            else if (!sunkenButton_.isNull()
+                     && (!(pBtn = qobject_cast<QPushButton*>(sunkenButton_.data()))
+                         || pBtn->menu() == w)
+                     && (!(tBtn = qobject_cast<QToolButton*>(sunkenButton_.data()))
+                         || tBtn->menu() == w
+                         || (tBtn->defaultAction() && tBtn->defaultAction()->menu() == w)))
+            {
+              QPoint wTopLeft = sunkenButton_.data()->mapToGlobal(QPoint(0,0));
+              if (wTopLeft.y() >= g.bottom())
+                dY +=  menuShadow_.at(1) + menuShadow_.at(3);
+              if (g.right() + 1 > wTopLeft.x() + sunkenButton_.data()->width())
               {
-                if (!sunkenButton_.isNull())
-                {
-                  QPoint wTopLeft = sunkenButton_.data()->mapToGlobal(QPoint(0,0));
-                  if (wTopLeft.y() >= g.bottom())
-                    dY +=  menuShadow_.at(1) + menuShadow_.at(3);
-                  if (g.right() + 1 > wTopLeft.x() + sunkenButton_.data()->width())
-                  {
-                    dX -= menuShadow_.at(2);
-                    qreal delta = menuShadow_.at(2)
-                                  - static_cast<qreal>(g.right() + 1 - (wTopLeft.x() + sunkenButton_.data()->width()));
-                    if (delta > 0)
-                      dX += delta;
-                    else
-                      dX -= qMin(menuShadow_.at(0), -delta);
-                  }
-                }
-                else if (!ag.isEmpty())
-                {
-                  if (g.top() != ag.top()
-                      && (g.bottom() == ag.bottom()
-                          || QCursor::pos(sc).y() >= g.bottom()))
-                  {
-                    dY += menuShadow_.at(1) + menuShadow_.at(3);
-                  }
-                  if (g.right() != ag.right()
-                      && (g.left() == ag.left()
-                          || QCursor::pos(sc).x() <= g.left()))
-                  {
-                    dX -= menuShadow_.at(2) + menuShadow_.at(0);
-                  }
-                }
+                dX -= menuShadow_.at(2);
+                qreal delta = menuShadow_.at(2)
+                              - static_cast<qreal>(g.right() + 1 - (wTopLeft.x() + sunkenButton_.data()->width()));
+                if (delta > 0)
+                  dX += delta;
+                else
+                  dX -= qMin(menuShadow_.at(0), -delta);
+              }
+            }
+            else if (!ag.isEmpty())
+            {
+              if (g.top() != ag.top()
+                  && (g.bottom() == ag.bottom()
+                      || QCursor::pos(sc).y() >= g.bottom()))
+              {
+                dY += menuShadow_.at(1) + menuShadow_.at(3);
+              }
+              if (g.right() != ag.right()
+                  && (g.left() == ag.left()
+                      || QCursor::pos(sc).x() <= g.left()))
+              {
+                dX -= menuShadow_.at(2) + menuShadow_.at(0);
               }
             }
           }
@@ -1151,69 +1151,68 @@ bool Style::eventFilter(QObject *o, QEvent *e)
               else
                 dX -= menuShadow_.at(2); // right shadow of the left menu
             }
-            else
+            else if (parentMenubar)
             {
-              if (parentMenubar)
-              {
-                QString group = tspec_.merge_menubar_with_toolbar ? "Toolbar" : "MenuBar";
-                if (parentMenubar->mapToGlobal(QPoint(0,0)).y() > g.bottom()) // menu is above menubar
-                  dY +=  menuShadow_.at(1) + menuShadow_.at(3) + static_cast<qreal>(getFrameSpec(group).top);
-                else
-                  dY -= static_cast<qreal>(getFrameSpec(group).bottom);
-
-                QPoint activeTopLeft = parentMenubar->mapToGlobal(parentMenubar->actionGeometry(
-                                                                   parentMenubar->activeAction())
-                                                                 .topLeft());
-                if (activeTopLeft.x() > g.left()) // because of the right screen border
-                {
-                  dX += menuShadow_.at(0);
-                  qreal delta = menuShadow_.at(0) - static_cast<qreal>(activeTopLeft.x() - g.left());
-                  if (delta > 0)
-                    dX -= delta;
-                  else
-                    dX += qMin(menuShadow_.at(2), -delta);
-                }
-              }
+              QString group = tspec_.merge_menubar_with_toolbar ? "Toolbar" : "MenuBar";
+              if (parentMenubar->mapToGlobal(QPoint(0,0)).y() > g.bottom()) // menu is above menubar
+                dY +=  menuShadow_.at(1) + menuShadow_.at(3) + static_cast<qreal>(getFrameSpec(group).top);
               else
+                dY -= static_cast<qreal>(getFrameSpec(group).bottom);
+
+              QPoint activeTopLeft = parentMenubar->mapToGlobal(parentMenubar->actionGeometry(
+                                                                 parentMenubar->activeAction())
+                                                               .topLeft());
+              if (activeTopLeft.x() > g.left()) // because of the right screen border
               {
-                if (!sunkenButton_.isNull()) // the menu is triggered by a button
-                {
-                  QPoint wTopLeft = sunkenButton_.data()->mapToGlobal(QPoint(0,0));
-                  if (wTopLeft.y() >= g.bottom()) // above the button (strange! Qt doesn't add 1px)
-                    dY +=  menuShadow_.at(1) + menuShadow_.at(3);
-                  if (wTopLeft.x() > g.left()) // because of the right screen border
-                  {
-                    dX += menuShadow_.at(0);
-                    qreal delta = menuShadow_.at(0) - static_cast<qreal>(wTopLeft.x() - g.left());
-                    if (delta > 0)
-                      dX -= delta;
-                    else
-                      dX += qMin(menuShadow_.at(2), -delta);
-                  }
-                }
-                else if (!ag.isEmpty()) // probably a panel menu
-                {
-                  /* snap to the screen bottom/right if possible and,
-                     as the last resort, consider the cursor position */
-                  if (g.top() != ag.top()
-                      && (g.bottom() == ag.bottom()
-                          || QCursor::pos(sc).y() >= g.bottom()))
-                  {
-                    dY += menuShadow_.at(1) + menuShadow_.at(3);
-                  }
-                  if (g.left() != ag.left()
-                      && (g.right() == ag.right()
-                          || QCursor::pos(sc).x() >= g.right() + 1))
-                  {
-                    dX += menuShadow_.at(0) + menuShadow_.at(2);
-                  }
-                }
+                dX += menuShadow_.at(0);
+                qreal delta = menuShadow_.at(0) - static_cast<qreal>(activeTopLeft.x() - g.left());
+                if (delta > 0)
+                  dX -= delta;
+                else
+                  dX += qMin(menuShadow_.at(2), -delta);
+              }
+            }
+            else if (!sunkenButton_.isNull()
+                     && (!(pBtn = qobject_cast<QPushButton*>(sunkenButton_.data()))
+                         || pBtn->menu() == w)
+                     && (!(tBtn = qobject_cast<QToolButton*>(sunkenButton_.data()))
+                         || tBtn->menu() == w
+                         || (tBtn->defaultAction() && tBtn->defaultAction()->menu() == w)))
+            { // the menu is triggered by a push or tool button
+              QPoint wTopLeft = sunkenButton_.data()->mapToGlobal(QPoint(0,0));
+              if (wTopLeft.y() >= g.bottom()) // above the button (strange! Qt doesn't add 1px)
+                dY +=  menuShadow_.at(1) + menuShadow_.at(3);
+              if (wTopLeft.x() > g.left()) // because of the right screen border
+              {
+                dX += menuShadow_.at(0);
+                qreal delta = menuShadow_.at(0) - static_cast<qreal>(wTopLeft.x() - g.left());
+                if (delta > 0)
+                  dX -= delta;
+                else
+                  dX += qMin(menuShadow_.at(2), -delta);
+              }
+            }
+            else if (!ag.isEmpty()) // probably a panel menu
+            {
+              /* snap to the screen bottom/right if possible and,
+                 as the last resort, consider the cursor position */
+              if (g.top() != ag.top()
+                  && (g.bottom() == ag.bottom()
+                      || QCursor::pos(sc).y() >= g.bottom()))
+              {
+                dY += menuShadow_.at(1) + menuShadow_.at(3);
+              }
+              if (g.left() != ag.left()
+                  && (g.right() == ag.right()
+                      || QCursor::pos(sc).x() >= g.right() + 1))
+              {
+                dX += menuShadow_.at(0) + menuShadow_.at(2);
               }
             }
           }
         }
         else if (!parentMenu && parentMenubar)
-        {
+        { // triggered by a menubar, without compositing or shadow
           QString group = tspec_.merge_menubar_with_toolbar ? "Toolbar" : "MenuBar";
           if (parentMenubar->mapToGlobal(QPoint(0,0)).y() > g.bottom()) // menu is above menubar
             dY += static_cast<qreal>(getFrameSpec(group).top);
@@ -1260,7 +1259,8 @@ bool Style::eventFilter(QObject *o, QEvent *e)
         }
 
         w->move(g.left() + DX, g.top() + DY);
-        movedMenus.insert(w);
+        movedMenus_.insert(w);
+        connect(w, &QObject::destroyed, this, &Style::forgetMovedMenu);
       }
       else if (tspec_.group_toolbar_buttons && qobject_cast<QToolButton*>(o))
       {
@@ -1445,88 +1445,87 @@ bool Style::eventFilter(QObject *o, QEvent *e)
     break;*/
 
   case QEvent::Hide:
-    if (qobject_cast<QToolButton*>(o))
+    if (w)
     {
-      if (tspec_.group_toolbar_buttons)
+      if (qobject_cast<QToolButton*>(o))
       {
-        if (QToolBar *toolBar = qobject_cast<QToolBar*>(w->parentWidget()))
+        if (tspec_.group_toolbar_buttons)
         {
-          if (toolBar->orientation() != Qt::Vertical)
-            toolBar->update();
+          if (QToolBar *toolBar = qobject_cast<QToolBar*>(w->parentWidget()))
+          {
+            if (toolBar->orientation() != Qt::Vertical)
+              toolBar->update();
+          }
+        }
+        //break; // toolbuttons may be animated (see below)
+      }
+      else if (w->isEnabled() && tspec_.animate_states)
+      {
+        if (w->inherits("QComboBoxPrivateContainer")
+            && qobject_cast<QComboBox*>(w->parentWidget()))
+        {
+          /* start with an appropriate state on closing popup, considering
+             that lineedits only have normal and focused states in Kvantum */
+          if ((tspec_.combo_as_lineedit || tspec_.square_combo_button)
+              && qobject_cast<QComboBox*>(w->parentWidget())->lineEdit())
+          {
+            animationStartState_ = "normal"; // -> QEvent::FocusIn
+          }
+          else
+            animationStartState_ = "c-toggled"; // distinguish it from a toggled button
+          /* ensure that the combobox will be animated on closing popup
+             (especially needed if the cursor has been on the popup) */
+          animatedWidget_ = w->parentWidget();
+          animationOpacity_ = 0;
+          break;
+        }
+        else if (w->windowType() == Qt::Popup
+                 || w->windowType() == Qt::ToolTip)
+        { // let the popup origin have a fade-out animation
+          animatedWidget_ = popupOrigins_.value(w);
+          forgetPopupOrigin(o);
+        }
+        /* let the state animation continue (not necessary but useful
+           for better flash prevention -- see FocusIn and FocusOut) */
+        else if ((animatedWidget_ == w && opacityTimer_->isActive())
+                 || (animatedWidgetOut_ == w && opacityTimerOut_->isActive()))
+        {
+          break;
         }
       }
-      //break; // toolbuttons may be animated (see below)
-    }
-    else if (w && w->isEnabled() && tspec_.animate_states)
-    {
-      if (w->inherits("QComboBoxPrivateContainer")
-          && qobject_cast<QComboBox*>(w->parentWidget()))
+
+      /* remove the widget from some lists when it becomes hidden */
+      if (qobject_cast<QMenu*>(w))
+        forgetMovedMenu(o);
+      if (!progressbars_.isEmpty() && qobject_cast<QProgressBar*>(o))
       {
-        /* start with an appropriate state on closing popup, considering
-           that lineedits only have normal and focused states in Kvantum */
-        if ((tspec_.combo_as_lineedit || tspec_.square_combo_button)
-            && qobject_cast<QComboBox*>(w->parentWidget())->lineEdit())
-        {
-          animationStartState_ = "normal"; // -> QEvent::FocusIn
-        }
-        else
-          animationStartState_ = "c-toggled"; // distinguish it from a toggled button
-        /* ensure that the combobox will be animated on closing popup
-           (especially needed if the cursor has been on the popup) */
-        animatedWidget_ = w->parentWidget();
-        animationOpacity_ = 0;
+        forgetProgressBar(o);
         break;
       }
-      else if (w->windowType() == Qt::Popup
-               || w->windowType() == Qt::ToolTip)
-      { // let the popup origin have a fade-out animation
-        animatedWidget_ = popupOrigins_.value(w);
-        popupOrigins_.remove(w);
-      }
-      /* let the state animation continue (not necessary but useful
-         for better flash prevention -- see FocusIn and FocusOut) */
-      else if ((animatedWidget_ == w && opacityTimer_->isActive())
-               || (animatedWidgetOut_ == w && opacityTimerOut_->isActive()))
+      else if (tspec_.animate_states
+               && (w->windowType() == Qt::Popup
+                   || w->windowType() == Qt::ToolTip))
       {
-        break;
+        forgetPopupOrigin(o);
+        break; // popups aren't animated (see below)
       }
     }
     /* Falls through. */
 
-  case QEvent::Destroy: // FIXME: Isn't QEvent::Hide enough?
-    if (w)
+  case QEvent::Destroy: // not necessary
+    if (w && tspec_.animate_states)
     {
-      if (qobject_cast<QMenu*>(w))
-        movedMenus.remove(w);
-
-      if (!progressbars_.isEmpty() && qobject_cast<QProgressBar*>(o))
+      if (animatedWidget_ == w)
       {
-        progressbars_.remove(w);
-        if (progressbars_.size() == 0)
-          progressTimer_->stop();
+        opacityTimer_->stop();
+        animatedWidget_ = nullptr;
+        animationOpacity_ = 100;
       }
-      else if (tspec_.animate_states)
+      if (animatedWidgetOut_ == w)
       {
-        if (w->windowType() == Qt::Popup
-            || w->windowType() == Qt::ToolTip)
-        {
-          popupOrigins_.remove(w);
-        }
-        else // popups aren't animated
-        {
-          if (animatedWidget_ == w)
-          {
-            opacityTimer_->stop();
-            animatedWidget_ = nullptr;
-            animationOpacity_ = 100;
-          }
-          if (animatedWidgetOut_ == w)
-          {
-            opacityTimerOut_->stop();
-            animatedWidgetOut_ = nullptr;
-            animationOpacityOut_ = 100;
-          }
-        }
+        opacityTimerOut_->stop();
+        animatedWidgetOut_ = nullptr;
+        animationOpacityOut_ = 100;
       }
     }
     break;
