@@ -204,7 +204,7 @@ typedef struct {
   bool groupbox_top_label;
   /* shift the contents of a pushbutton when it's down?
      (the contennts are shifted by default) */
-  bool button_contents_shift;
+  //bool button_contents_shift;
   /* draw scrollbars within view */
   bool scrollbar_in_view;
   /* show scrollbars only when needed? */
@@ -543,7 +543,7 @@ static inline void default_theme_spec(theme_spec &tspec) {
   tspec.scrollable_menu = true;
   tspec.fill_rubberband = false;
   tspec.groupbox_top_label = false;
-  tspec.button_contents_shift = true;
+  //tspec.button_contents_shift = true;
   tspec.scrollbar_in_view = false;
   tspec.transient_scrollbar = false;
   tspec.transient_groove = false;
